@@ -27,6 +27,8 @@ from ansible_collections.community.crypto.plugins.module_utils.acme.backend_open
 
 from ansible_collections.community.crypto.plugins.module_utils.acme.backend_cryptography import (
     CryptographyBackend,
+    CRYPTOGRAPHY_ERROR,
+    CRYPTOGRAPHY_MINIMAL_VERSION,
     CRYPTOGRAPHY_VERSION,
     HAS_CURRENT_CRYPTOGRAPHY,
 )
@@ -36,6 +38,7 @@ from ansible_collections.community.crypto.plugins.module_utils.acme.errors impor
     NetworkException,
     ModuleFailException,
     KeyParsingError,
+    format_http_status,
 )
 
 from ansible_collections.community.crypto.plugins.module_utils.acme.utils import (
@@ -43,7 +46,7 @@ from ansible_collections.community.crypto.plugins.module_utils.acme.utils import
 )
 
 try:
-    import ipaddress
+    import ipaddress  # noqa: F401, pylint: disable=unused-import
 except ImportError:
     HAS_IPADDRESS = False
     IPADDRESS_IMPORT_ERROR = traceback.format_exc()
@@ -52,7 +55,8 @@ else:
     IPADDRESS_IMPORT_ERROR = None
 
 
-RETRY_STATUS_CODES = (408, 429, 503)
+# -1 usually means connection problems
+RETRY_STATUS_CODES = (-1, 408, 429, 503)
 
 
 def _decode_retry(module, response, info, retry_count):
@@ -67,7 +71,7 @@ def _decode_retry(module, response, info, retry_count):
         retry_after = min(max(1, int(info.get('retry-after'))), 60)
     except (TypeError, ValueError) as dummy:
         retry_after = 10
-    module.log('Retrieved a %d HTTP status on %s, retrying in %s seconds' % (info['status'], info['url'], retry_after))
+    module.log('Retrieved a %s HTTP status on %s, retrying in %s seconds' % (format_http_status(info['status']), info['url'], retry_after))
 
     time.sleep(retry_after)
     return True
@@ -136,8 +140,15 @@ class ACMEDirectory(object):
                 retry_count += 1
                 continue
             if info['status'] not in (200, 204):
-                raise NetworkException("Failed to get replay-nonce, got status {0}".format(info['status']))
-            return info['replay-nonce']
+                raise NetworkException("Failed to get replay-nonce, got status {0}".format(format_http_status(info['status'])))
+            if 'replay-nonce' in info:
+                return info['replay-nonce']
+            self.module.log(
+                'HEAD to {0} did return status {1}, but no replay-nonce header!'.format(url, format_http_status(info['status'])))
+            if retry_count >= 5:
+                raise ACMEProtocolException(
+                    self.module, msg='Was not able to obtain nonce, giving up after 5 retries', info=info, response=response)
+            retry_count += 1
 
 
 class ACMEClient(object):
@@ -399,8 +410,19 @@ def create_backend(module, needs_acme_v2):
 
     # Create backend object
     if backend == 'cryptography':
+        if CRYPTOGRAPHY_ERROR is not None:
+            # Either we couldn't import cryptography at all, or there was an unexpected error
+            if CRYPTOGRAPHY_VERSION is None:
+                msg = missing_required_lib('cryptography')
+            else:
+                msg = 'Unexpected error while preparing cryptography: {0}'.format(CRYPTOGRAPHY_ERROR.splitlines()[-1])
+            module.fail_json(msg=msg, exception=CRYPTOGRAPHY_ERROR)
         if not HAS_CURRENT_CRYPTOGRAPHY:
-            module.fail_json(msg=missing_required_lib('cryptography'))
+            # We succeeded importing cryptography, but its version is too old.
+            module.fail_json(
+                msg='Found cryptography, but only version {0}. {1}'.format(
+                    CRYPTOGRAPHY_VERSION,
+                    missing_required_lib('cryptography >= {0}'.format(CRYPTOGRAPHY_MINIMAL_VERSION))))
         module.debug('Using cryptography backend (library version {0})'.format(CRYPTOGRAPHY_VERSION))
         module_backend = CryptographyBackend(module)
     elif backend == 'openssl':
